@@ -1028,7 +1028,16 @@ models = [
         ],
         sha='462f15d668c046d38e27d3df01fe8142dd004cb4',
         filename='onnx/models/yolov8x.onnx'),
-
+    Model(
+        name='yolov9t',
+        url='https://dl.opencv.org/models/yolov9/yolov9t.onnx',
+        sha='330292f15e1b312b11ce58e70a9e455d54415fa3',
+        filename='onnx/models/yolov9t.onnx'),
+    Model(
+        name='yolov10s',
+        url='https://dl.opencv.org/models/yolov10/yolov10s.onnx',
+        sha='5311212e431912a27d5f54b3a5277bc573890a99',
+        filename='onnx/models/yolov10s.onnx'),
     Model(
         name='yolo_nas_s',
         url='https://dl.opencv.org/models/yolo-nas/yolo_nas_s.onnx',
@@ -1217,23 +1226,7 @@ models = [
             'https://dl.opencv.org/models/intel_open_model_zoo/person-detection-retail-0013/FP32/person-detection-retail-0013.bin'
         ],
         sha='682e59855466f88eb0cab9d40ca16e9fd6303bea',
-        filename='../intel/person-detection-retail-0013/FP32/person-detection-retail-0013.xml'),
-    Model(
-        name='person-vehicle-bike-detection-2004-fp32 (xml)',
-        url=[
-            'https://storage.openvinotoolkit.org/repositories/open_model_zoo/2023.0/models_bin/1/person-vehicle-bike-detection-2004/FP32/person-vehicle-bike-detection-2004.xml',
-            'https://dl.opencv.org/models/intel_open_model_zoo/person-vehicle-bike-detection-2004/FP32/person-vehicle-bike-detection-2004.xml'
-        ],
-        sha='55eef16bc3eb58c255ea8edb77216d2ec408c0f8',
-        filename='../intel/person-vehicle-bike-detection-2004/FP32/person-vehicle-bike-detection-2004.xml'),
-    Model(
-        name='person-vehicle-bike-detection-2004-fp32 (weights)',
-        url=[
-            'https://storage.openvinotoolkit.org/repositories/open_model_zoo/2023.0/models_bin/1/person-vehicle-bike-detection-2004/FP32/person-vehicle-bike-detection-2004.bin',
-            'https://dl.opencv.org/models/intel_open_model_zoo/person-vehicle-bike-detection-2004/FP32/person-vehicle-bike-detection-2004.bin'
-        ],
-        sha='b4b901f53234e87227b81046d7e7aed9a7e6f2c3',
-        filename='../intel/person-vehicle-bike-detection-2004/FP32/person-vehicle-bike-detection-2004.xml'),
+        filename='../intel/person-detection-retail-0013/FP32/person-detection-retail-0013.bin'),
 ]
 
 # Note: models will be downloaded to current working directory
